from base64 import urlsafe_b64decode

from django.contrib.auth.decorators import login_required
from django.db.models import Count
from django.http import HttpResponse
from django.shortcuts import get_object_or_404, render

from shiftregister.fallback.models import TeamMember

# Create your views here.


def my_fallback_shifts(request, team_member_id):
    try:
        team_member_id = int.from_bytes(
            urlsafe_b64decode(team_member_id), byteorder="big"
        )
    except Exception:
        team_member_id = None

    team_member = get_object_or_404(TeamMember, pk=team_member_id)

    is_draw = False
    if request.method == "POST":
        team_member.assign_random_shifts()
        is_draw = True

    context = {
        "team_member": team_member,
        "assignments": team_member.fallbackassignment_set.order_by(
            "shift__start_at"
        ).all(),
        # "shifts": team_member.fallback_shifts.order_by("start_at").all(),
        "is_draw": is_draw,
    }
    return render(request, "my_fallback_shifts.html", context)


@login_required
def team_members(request):
    response = HttpResponse(
        "".join(
            f"{member.name} {member.url()}\n"
            for member in TeamMember.objects.annotate(
                shift_count=Count("fallback_shifts")
            )
            .filter(fallback_shifts__gt=0)
            .order_by("name")
        )
    )
    response.headers["Content-Type"] = "text/plain; charset=utf-8"

    return response
