from secrets import token_urlsafe

from django.db import models

from shiftregister.app.models import Helper


class Feedback(models.Model):
    helper = models.OneToOneField(Helper, primary_key=True, on_delete=models.CASCADE)

    class PartyState(models.TextChoices):
        YES = "yes", "ja"
        NO = "no", "nein"
        MAYBE = "maybe", "vielleicht"

    party = models.CharField(
        max_length=7,
        choices=PartyState.choices,
    )
    next_year = models.BooleanField()
    feedback_text = models.TextField(blank=True, default="")

    def __str__(self):
        return f"Feedback by {self.helper.name}"

    def color(self):
        return {"yes": "is-success", "no": "is-danger", "maybe": "is-warning"}[
            self.party
        ]


class ShareToken(models.Model):
    token = models.CharField(max_length=43, default=token_urlsafe, primary_key=True)
    name = models.CharField(max_length=200)

    def __str__(self):
        return self.name
