from django.conf import settings
from django.core.exceptions import ImproperlyConfigured

from .backends.abc import Receiver
from .utils import import_class

__all__ = ("receiver",)


def resolve_backend():
    receiver_cls = settings.SMS_INBOUND_BACKEND
    if isinstance(receiver_cls, str):
        receiver_cls = import_class(receiver_cls, "Receiver")

    if not issubclass(receiver_cls, Receiver):
        raise ImproperlyConfigured(
            "SMS_INBOUND_BACKEND must be a subclass of shiftregister.messaging.backends.abc.Receiver"
        )

    receiver = receiver_cls()
    if receiver.handle is not None and settings.SMS_WEBHOOK_SECRET is None:
        raise ImproperlyConfigured(
            "the specified SMS_INBOUND_BACKEND requires SMS_WEBHOOK_SECRET to be set"
        )

    return receiver


receiver = resolve_backend()
